# CAMEL CASE ALL THE THINGS (for legacy support)

#' @rdname dev_slackr
#' @export
dev.slackr <- dev_slackr

#' @rdname save_slackr
#' @export
save.slackr <- save_slackr

#' @rdname slackr_bot
#' @export
slackrBot <- slackr_bot

#' @rdname slackr_chtrans
#' @export
slackrChtrans <- slackr_chtrans

#' @rdname slackr_chtrans
#' @export
slackrChTrans <- slackr_chtrans

#' @rdname slackr_channels
#' @export
slackrChannels <- slackr_channels

#' @rdname slackr_ims
#' @export
slackrIms <- slackr_ims

#' @rdname slackr_msg
#' @export
slackrMsg <- slackr_msg

#' @rdname slackr_setup
#' @export
slackrSetup <- slackr_setup

#' @rdname slackr_upload
#' @export
slackrUpload <- slackr_upload

#' @rdname slackr_users
#' @export
slackrUsers <- slackr_users

#' @rdname text_slackr
#' @export
textSlackr <- text_slackr
